@@ -125,14 +125,9 @@ def test_env_w_custom_converter():
 
 
 def test_env_lowercase():
-    with pytest.warns(None) as record:
-        environ["SANIC_test_answer"] = "42"
-        app = Sanic(name="Test")
-        assert app.config.test_answer == 42
-    assert str(record[0].message) == (
-        "[DEPRECATION v22.9] Lowercase environment variables will not be "
-        "loaded into Sanic config beginning in v22.9."
-    )
+    environ["SANIC_test_answer"] = "42"
+    app = Sanic(name="Test")
+    assert "test_answer" not in app.config
     del environ["SANIC_test_answer"]
 
 
@@ -293,26 +288,21 @@ def test_config_custom_defaults_with_env():
         del environ[key]
 
 
-def test_config_access_log_passing_in_run(app: Sanic):
-    assert app.config.ACCESS_LOG is True
+@pytest.mark.parametrize("access_log", (True, False))
+def test_config_access_log_passing_in_run(app: Sanic, access_log):
+    assert app.config.ACCESS_LOG is False
 
     @app.listener("after_server_start")
     async def _request(sanic, loop):
         app.stop()
 
-    app.run(port=1340, access_log=False)
-    assert app.config.ACCESS_LOG is False
-
-    app.router.reset()
-    app.signal_router.reset()
-
-    app.run(port=1340, access_log=True)
-    assert app.config.ACCESS_LOG is True
+    app.run(port=1340, access_log=access_log, single_process=True)
+    assert app.config.ACCESS_LOG is access_log
 
 
 @pytest.mark.asyncio
 async def test_config_access_log_passing_in_create_server(app: Sanic):
-    assert app.config.ACCESS_LOG is True
+    assert app.config.ACCESS_LOG is False
 
     @app.listener("after_server_start")
     async def _request(sanic, loop):
