@@ -97,15 +97,15 @@ def test_auto_fallback_with_content_type(app):
 def test_route_error_format_set_on_auto(app):
     @app.get("/text")
     def text_response(request):
-        return text(request.route.ctx.error_format)
+        return text(request.route.extra.error_format)
 
     @app.get("/json")
     def json_response(request):
-        return json({"format": request.route.ctx.error_format})
+        return json({"format": request.route.extra.error_format})
 
     @app.get("/html")
     def html_response(request):
-        return html(request.route.ctx.error_format)
+        return html(request.route.extra.error_format)
 
     _, response = app.test_client.get("/text")
     assert response.text == "text"
@@ -353,7 +353,7 @@ def test_config_fallback_before_and_after_startup(app):
 
     _, response = app.test_client.get("/error")
     assert response.status == 500
-    assert response.content_type == "text/plain; charset=utf-8"
+    assert response.content_type == "application/json"
 
 
 def test_config_fallback_using_update_dict(app):
