@@ -36,7 +36,7 @@ def test_app(app: Sanic):
 
 
 @pytest.fixture
-def runner(test_app):
+def runner(test_app: Sanic):
     client = ReusableClient(test_app, port=PORT)
     client.run()
     yield client
@@ -44,7 +44,7 @@ def runner(test_app):
 
 
 @pytest.fixture
-def client(runner):
+def client(runner: ReusableClient):
     client = namedtuple("Client", ("raw", "send", "recv"))
 
     raw = RawClient(runner.host, runner.port)
