@@ -10,7 +10,7 @@ import pytest
 import sanic
 
 from sanic import Sanic
-from sanic.log import LOGGING_CONFIG_DEFAULTS, logger
+from sanic.log import LOGGING_CONFIG_DEFAULTS, Colors, logger
 from sanic.response import text
 
 
@@ -166,6 +166,7 @@ def test_access_log_client_ip_remote_addr(monkeypatch):
     monkeypatch.setattr(sanic.http.http1, "access_logger", access)
 
     app = Sanic("test_logging")
+    app.config.ACCESS_LOG = True
     app.config.PROXIES_COUNT = 2
 
     @app.route("/")
@@ -193,6 +194,7 @@ def test_access_log_client_ip_reqip(monkeypatch):
     monkeypatch.setattr(sanic.http.http1, "access_logger", access)
 
     app = Sanic("test_logging")
+    app.config.ACCESS_LOG = True
 
     @app.route("/")
     async def handler(request):
@@ -248,3 +250,14 @@ def test_verbosity(app, caplog, app_verbosity, log_verbosity, exists):
 
     if app_verbosity == 0:
         assert ("sanic.root", logging.INFO, "DEFAULT") in caplog.record_tuples
+
+
+def test_colors_enum_format():
+    assert f"{Colors.END}" == Colors.END.value
+    assert f"{Colors.BOLD}" == Colors.BOLD.value
+    assert f"{Colors.BLUE}" == Colors.BLUE.value
+    assert f"{Colors.GREEN}" == Colors.GREEN.value
+    assert f"{Colors.PURPLE}" == Colors.PURPLE.value
+    assert f"{Colors.RED}" == Colors.RED.value
+    assert f"{Colors.SANIC}" == Colors.SANIC.value
+    assert f"{Colors.YELLOW}" == Colors.YELLOW.value
