@@ -803,6 +803,21 @@ def test_static_add_route(app, strict_slashes):
     assert response.text == "OK2"
 
 
+@pytest.mark.parametrize("unquote", [True, False, None])
+def test_unquote_add_route(app, unquote):
+    async def handler1(_, foo):
+        return text(foo)
+
+    app.add_route(handler1, "/<foo>", unquote=unquote)
+    value = "啊" if unquote else r"%E5%95%8A"
+
+    _, response = app.test_client.get("/啊")
+    assert response.text == value
+
+    _, response = app.test_client.get(r"/%E5%95%8A")
+    assert response.text == value
+
+
 def test_dynamic_add_route(app):
 
     results = []
@@ -1266,3 +1281,22 @@ async def test_added_callable_route_ctx_kwargs(app):
 
     assert request.route.ctx.foo() == "foo"
     assert await request.route.ctx.bar() == 99
+
+
+@pytest.mark.asyncio
+async def test_duplicate_route_deprecation(app):
+    @app.route("/foo", name="duped")
+    async def handler_foo(request):
+        return text("...")
+
+    @app.route("/bar", name="duped")
+    async def handler_bar(request):
+        return text("...")
+
+    message = (
+        r"\[DEPRECATION v23\.3\] Duplicate route names detected: "
+        r"test_duplicate_route_deprecation\.duped\. In the future, "
+        r"Sanic will enforce uniqueness in route naming\."
+    )
+    with pytest.warns(DeprecationWarning, match=message):
+        await app._startup()
