@@ -7,7 +7,7 @@ import pytest
 
 from sanic_routing.exceptions import NotFound
 
-from sanic import Blueprint
+from sanic import Blueprint, Sanic, empty
 from sanic.exceptions import InvalidSignal, SanicException
 
 
@@ -20,6 +20,31 @@ def test_add_signal(app):
     assert len(app.signal_router.routes) == 1
 
 
+def test_add_signal_method_handler(app):
+    counter = 0
+
+    class TestSanic(Sanic):
+        def __init__(self, *args, **kwargs):
+            super().__init__(*args, **kwargs)
+            self.add_signal(
+                self.after_routing_signal_handler, "http.routing.after"
+            )
+
+        def after_routing_signal_handler(self, *args, **kwargs):
+            nonlocal counter
+            counter += 1
+
+    app = TestSanic("Test")
+    assert len(app.signal_router.routes) == 1
+
+    @app.route("/")
+    async def handler(_):
+        return empty()
+
+    app.test_client.get("/")
+    assert counter == 1
+
+
 def test_add_signal_decorator(app):
     @app.signal("foo.bar.baz")
     def sync_signal(*_):
@@ -289,10 +314,10 @@ async def test_dispatch_signal_triggers_event_on_bp(app):
     waiter = bp.event("foo.bar.baz")
     assert isawaitable(waiter)
 
-    fut = asyncio.ensure_future(do_wait())
+    fut = do_wait()
     for signal in signal_group:
         signal.ctx.event.set()
-    await fut
+    await asyncio.gather(fut)
 
     assert bp_counter == 1
 
